@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2024 R M Yorston
+// Copyright (C) 2011-2025 R M Yorston
 // Licence: GPLv2+
 
 import Atk from 'gi://Atk';
@@ -403,7 +403,8 @@ class WindowListItem extends TooltipChild {
             'notify::wm-class',
             () => this._updateIcon(), GObject.ConnectFlags.AFTER,
             'notify::gtk-application-id',
-            () => this._updateIcon(), GObject.ConnectFlags.AFTER);
+            () => this._updateIcon(), GObject.ConnectFlags.AFTER,
+            this);
 
         this._notifyFocusId =
             global.display.connect('notify::focus-window',
@@ -484,6 +485,7 @@ class WindowListItem extends TooltipChild {
 
     _onDestroy() {
         global.display.disconnect(this._notifyFocusId);
+        this.metaWindow.disconnectObject(this);
         this.tooltip.destroy();
         this.tooltip = null;
         this.rightClickMenu.destroy();
